==> deepin-voice-recorder_1.3.7.orig.tar.gz: deepin-voice-recorder-1.3.7/translations/deepin-voice-recorder_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation>Показати у файловому менеджері</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation>У смітник</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation>Новий запис</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation>Відкрити каталог зберігання</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation>Deepin Voice Recorder - це елегантна і проста у використанні програма для запису голосу зі зручним інтерфейсом. Окрім самого запису, програма підтримує відтворення записів, керування списком записів та інші функції.</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Диктофон</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Диктофон</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation>Новий запис</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation>Запис</translation>
    </message>
</context>
</TS>

==> deepin-voice-recorder_1.3.9.orig.tar.gz: deepin-voice-recorder-1.3.9/translations/deepin-voice-recorder_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation>Показати у файловому менеджері</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation>Перемістити в кошик</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation>Новий запис</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation>Відкрити каталог зберігання</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation>Deepin Voice Recorder - це елегантна і проста у використанні програма для запису голосу зі зручним інтерфейсом. Окрім самого запису, програма підтримує відтворення записів, керування списком записів та інші функції.</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Диктофон</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation>Deepin Диктофон</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation>Новий запис</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation>Запис</translation>
    </message>
</context>
</TS>
